==> kdeedu-3.0.1.tar.bz2: kdeedu-3.0.1/keduca/keduca/kradioeduca.h <==
/***************************************************************************
                          kradioeduca.h  -  description
                             -------------------
    begin                : Wed Sep 6 2000
    copyright            : (C) 2000 by Javier Campos Morales
    email                : javi_c@ctv.es
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KRADIOEDUCA_H
#define KRADIOEDUCA_H

#include <qwidget.h>

#include <qradiobutton.h>
#include <qsimplerichtext.h>

/**QRadioButton with wordwrap and richtext features
  *@author Javier Campos Morales
  */

class KRadioEduca : public QRadioButton {
   Q_OBJECT
public: 
	KRadioEduca(QWidget *parent=0, const char *name=0);
	~KRadioEduca();
private: // Private attributes
  /** Rich Text */
  QSimpleRichText *doc;
protected: // Protected methods
  /** reimpl */
  void drawButtonLabel( QPainter *p);
};

#endif

==> kdeedu-3.1.3.tar.bz2: kdeedu-3.1.3/keduca/keduca/kradioeduca.h <==
/***************************************************************************
                          kradioeduca.h  -  description
                             -------------------
    begin                : Wed Sep 6 2000
    copyright            : (C) 2000 by Javier Campos Morales
    email                : javi_c@ctv.es
***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KRADIOEDUCA_H
#define KRADIOEDUCA_H

#include <qwidget.h>

#include <qradiobutton.h>
#include <qsimplerichtext.h>

/**QRadioButton with wordwrap and richtext features
 *@author Javier Campos Morales
 */

class KRadioEduca : public QRadioButton {
    Q_OBJECT

public:
    KRadioEduca(QWidget *parent=0, const char *name=0);
    ~KRadioEduca();

private: // Private attributes
    /** Rich Text */
    QSimpleRichText *_doc;

protected: // Protected methods
    /** reimpl */
    void drawButtonLabel( QPainter *p);
};

#endif
